Glyphon provides a simple way to render 2D text with wgpu, cosmic-text and etagere.
Re-exports
pub use ramp_text;pub use ramp_text::fontdb;pub use ramp_text::Action;pub use ramp_text::Affinity;pub use ramp_text::Attrs;pub use ramp_text::AttrsList;pub use ramp_text::AttrsOwned;pub use ramp_text::Buffer;pub use ramp_text::BufferLine;pub use ramp_text::CacheKey;pub use ramp_text::Color;pub use ramp_text::Command;pub use ramp_text::Cursor;pub use ramp_text::Edit;pub use ramp_text::Editor;pub use ramp_text::Family;pub use ramp_text::FamilyOwned;pub use ramp_text::Font;pub use ramp_text::FontSystem;pub use ramp_text::LayoutCursor;pub use ramp_text::LayoutGlyph;pub use ramp_text::LayoutLine;pub use ramp_text::LayoutRun;pub use ramp_text::LayoutRunIter;pub use ramp_text::Metrics;pub use ramp_text::ShapeGlyph;pub use ramp_text::ShapeLine;pub use ramp_text::ShapeSpan;pub use ramp_text::ShapeWord;pub use ramp_text::Shaping;pub use ramp_text::Stretch;pub use ramp_text::Style;pub use ramp_text::SubpixelBin;pub use ramp_text::SwashCache;pub use ramp_text::SwashContent;pub use ramp_text::SwashImage;pub use ramp_text::Weight;pub use ramp_text::Wrap;
Structs
- Cache
- A cache to share common resources (e.g., pipelines, layouts, shaders) between multiple text renderers.
- Custom
Glyph - A custom glyph to render
- Rasterize
Custom Glyph Request - A request to rasterize a custom glyph
- Rasterized
Custom Glyph - A rasterized custom glyph
- Resolution
- The screen resolution to use when rendering text.
- Text
Area - A text area containing text to be rendered along with its overflow behavior.
- Text
Atlas - An atlas containing a cache of rasterized glyphs that can be rendered.
- Text
Bounds - Controls the visible area of the text. Any text outside of the visible area will be clipped.
- Text
Renderer - A text renderer that uses cached glyphs to render text into an existing render pass.
- Viewport
- Controls the visible area of all text for a given renderer. Any text outside of the visible area will be clipped.
Enums
- Color
Mode - The color mode of a
TextAtlas. - Content
Type - The type of image data contained in a rasterized glyph
- Prepare
Error - An error that occurred while preparing text for rendering.
- Render
Error - An error that occurred while rendering text.